@@ -15,9 +15,10 @@ logger = logging.getLogger('aug_sfutils.journal')
 
 # Select the correct library
 
-libjournalso = '/afs/ipp/aug-ads/diags/@sys/lib64/libjournal.so'
-#libjournalso = '/afs/ipp/u/jcf/journal/oci/@sys/libjournal.so'
-libjournal   = ct.cdll.LoadLibrary(libjournalso)
+libjouso = '/afs/ipp/aug-ads/diags/@sys/lib64/libjournal.so'
+if not os.path.isfile(libjouso):
+    libjouso = '/afs/ipp-garching.mpg.de/aug/ads-diags/amd64_sles15/lib64/libjournal.so'
+libjournal   = ct.cdll.LoadLibrary(libjouso)
 
 date_fmt = '%Y-%m-%d'
 
