@@ -5,14 +5,7 @@ if os.name == 'nt':
 else:
     afs_home = '/afs/ipp-garching.mpg.de/home'
 
-fmt = logging.Formatter('%(asctime)s | %(name)s | %(levelname)s: %(message)s', '%Y-%m-%d %H:%M:%S')
-hnd = logging.StreamHandler()
-hnd.setFormatter(fmt)
-hnd.setLevel(level=logging.INFO)
-logger = logging.getLogger('manage_ed')
-logger.addHandler(hnd)
-logger.setLevel(logging.INFO)
-logger.propagate = False
+logger = logging.getLogger('aug_sfutils.manage_ed')
 
 
 def sf_path(nshot, diag, exp='AUGD', ed=0):
