@@ -1,7 +1,7 @@
 import os, logging
 from struct import unpack
 import numpy as np
-from . import sfdics, str_byt
+from aug_sfutils import sfdics, str_byt
 
 n_rel = 8
 
