@@ -168,6 +168,8 @@ class SFREAD:
         self.exp = None
         self.status = False
         self.open(*args, **kwargs)
+        if len(args) > 2:
+            logger.warning('More than 2 explicit arguments: only the first two (diag, shot) are retained')
 
 
     def open(self, *args, **kwargs):
